# vim: set fileencoding=utf-8 :
###############################################################################
#                                                                             #
# Copyright (c) 2019 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.editor module of the BEAT platform.           #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

import os
import sys
import tempfile
import pytest
import pkg_resources
import subprocess
import shutil
import importlib


if sys.platform == "darwin":
    prefix_folder = tempfile.mkdtemp(prefix=__name__, suffix=".prefix", dir="/tmp")
else:
    prefix_folder = tempfile.mkdtemp(prefix=__name__, suffix=".prefix")


prefix = os.path.join(prefix_folder, "prefix")


@pytest.fixture(scope="module")
def test_prefix():
    prefixes = [
        pkg_resources.resource_filename("beat.backend.python.test", "prefix"),
        pkg_resources.resource_filename("beat.core.test", "prefix"),
    ]

    for path in prefixes:
        subprocess.check_call(["rsync", "-arz", path, prefix_folder])

    yield prefix

    shutil.rmtree(prefix_folder)

    # Getting the prefix from beat.core triggers its setup_package but not the
    # corresponding tear down, therefore trigger it manually
    beat_core_test = importlib.import_module("beat.core.test")
    teardown_package = getattr(beat_core_test, "teardown_package")
    teardown_package()
