#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.cmdline module of the BEAT platform.          #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

"""
Test the utils.py file
"""

import os

import pkg_resources
from .. import utils


DATA_PATH = pkg_resources.resource_filename("beat.editor.test", "reference_data")


def compare_with_reference(generated, reference_file_name):
    """ Compare the given generated code with the content of the reference file
    """

    with open(os.path.join(DATA_PATH, reference_file_name)) as reference_file:
        reference = reference_file.read()
        return generated == reference


def test_generate_empty_database():
    database = utils.generate_database()
    assert compare_with_reference(database, "empty_database.py")


def test_generate_empty_algorithm():
    alg = {
        "name": "user/alg/1",
        "contents": {"splittable": True, "groups": [], "uses": {}},
    }
    algorithm = utils.generate_algorithm(alg["contents"])
    assert compare_with_reference(algorithm, "empty_algorithm.py")


def test_generate_empty_library():
    library = utils.generate_library()
    assert compare_with_reference(library, "empty_library.py")
